Class: DocSpring::ApiClient

Inherits:
Object
  • Object
show all
Defined in:
lib/docspring/api_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(config = Configuration.default) ⇒ ApiClient

Initializes the ApiClient

Parameters:

  • config (Hash) (defaults to: Configuration.default)

    a customizable set of options

Options Hash (config):

  • Configuration (Configuration)

    for initializing the object, default to Configuration.default



33
34
35
36
37
38
39
40
# File 'lib/docspring/api_client.rb', line 33

def initialize(config = Configuration.default)
  @config = config
  @user_agent = "docspring-ruby-#{VERSION}"
  @default_headers = {
    'Content-Type' => 'application/json',
    'User-Agent' => @user_agent
  }
end

Instance Attribute Details

#configObject

The Configuration object holding settings to be used in the API client.



24
25
26
# File 'lib/docspring/api_client.rb', line 24

def config
  @config
end

#default_headersHash

Defines the headers to be used in HTTP requests of all API calls by default.

Returns:

  • (Hash)


29
30
31
# File 'lib/docspring/api_client.rb', line 29

def default_headers
  @default_headers
end

Class Method Details

.defaultObject



42
43
44
# File 'lib/docspring/api_client.rb', line 42

def self.default
  @@default ||= ApiClient.new
end

Instance Method Details

#build_collection_param(param, collection_format) ⇒ Object

Build parameter value according to the given collection format.

Parameters:

  • collection_format (String)

    one of :csv, :ssv, :tsv, :pipes and :multi



396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/docspring/api_client.rb', line 396

def build_collection_param(param, collection_format)
  case collection_format
  when :csv
    param.join(',')
  when :ssv
    param.join(' ')
  when :tsv
    param.join("\t")
  when :pipes
    param.join('|')
  when :multi
    # return the array directly as typhoeus will handle it as expected
    param
  else
    fail "unknown collection format: #{collection_format.inspect}"
  end
end

#build_request(http_method, path, opts = {}) ⇒ Typhoeus::Request

Builds the HTTP request

Parameters:

  • http_method (String)

    HTTP method/verb (e.g. POST)

  • path (String)

    URL path (e.g. /account/new)

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :header_params (Hash)

    Header parameters

  • :query_params (Hash)

    Query parameters

  • :form_params (Hash)

    Query parameters

  • :body (Object)

    HTTP body (JSON/XML)

Returns:

  • (Typhoeus::Request)

    A Typhoeus Request



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/docspring/api_client.rb', line 113

def build_request(http_method, path, opts = {})
  url = build_request_url(path, opts)
  http_method = http_method.to_sym.downcase

  header_params = @default_headers.merge(opts[:header_params] || {})
  query_params = opts[:query_params] || {}
  form_params = opts[:form_params] || {}
  follow_location = opts[:follow_location] || true

  update_params_for_auth! header_params, query_params, opts[:auth_names]

  # set ssl_verifyhosts option based on @config.verify_ssl_host (true/false)
  _verify_ssl_host = @config.verify_ssl_host ? 2 : 0

  req_opts = {
    :method => http_method,
    :headers => header_params,
    :params => query_params,
    :params_encoding => @config.params_encoding,
    :timeout => @config.timeout,
    :ssl_verifypeer => @config.verify_ssl,
    :ssl_verifyhost => _verify_ssl_host,
    :sslcert => @config.cert_file,
    :sslkey => @config.key_file,
    :verbose => @config.debugging,
    :followlocation => follow_location
  }

  # set custom cert, if provided
  req_opts[:cainfo] = @config.ssl_ca_cert if @config.ssl_ca_cert

  if [:post, :patch, :put, :delete].include?(http_method)
    req_body = build_request_body(header_params, form_params, opts[:body])
    req_opts.update :body => req_body
    if @config.debugging
      @config.logger.debug "HTTP request body param ~BEGIN~\n#{req_body}\n~END~\n"
    end
  end

  Typhoeus::Request.new(url, req_opts)
end

#build_request_body(header_params, form_params, body) ⇒ String

Builds the HTTP request body

Parameters:

  • header_params (Hash)

    Header parameters

  • form_params (Hash)

    Query parameters

  • body (Object)

    HTTP body (JSON/XML)

Returns:

  • (String)

    HTTP body data in the form of string



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/docspring/api_client.rb', line 161

def build_request_body(header_params, form_params, body)
  # http form
  if header_params['Content-Type'] == 'application/x-www-form-urlencoded' ||
      header_params['Content-Type'] == 'multipart/form-data'
    data = {}
    form_params.each do |key, value|
      case value
      when ::File, ::Array, nil
        # let typhoeus handle File, Array and nil parameters
        data[key] = value
      else
        data[key] = value.to_s
      end
    end
  elsif body
    data = body.is_a?(String) ? body : body.to_json
  else
    data = nil
  end
  data
end

#build_request_url(path, opts = {}) ⇒ Object



317
318
319
320
321
# File 'lib/docspring/api_client.rb', line 317

def build_request_url(path, opts = {})
  # Add leading and trailing slashes to path
  path = "/#{path}".gsub(/\/+/, '/')
  @config.base_url(opts[:operation]) + path
end

#call_api(http_method, path, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Call an API with given options.

Returns:

  • (Array<(Object, Integer, Hash)>)

    an array of 3 elements: the data deserialized from response body (may be a Tempfile or nil), response status code and response headers.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/docspring/api_client.rb', line 50

def call_api(http_method, path, opts = {})
  request = build_request(http_method, path, opts)
  tempfile = download_file(request) if opts[:return_type] == 'File'
  response = request.run

  if @config.debugging
    @config.logger.debug "HTTP response body ~BEGIN~\n#{response.body}\n~END~\n"
  end

  unless response.success?
    if response.timed_out?
      fail ApiError.new('Connection timed out')
    elsif response.code == 0
      # Errors from libcurl will be made visible here
      fail ApiError.new(:code => 0,
                        :message => response.return_message)
    else
      # <--------------- BEGIN DOCSPRING CUSTOMIZATION ----------------->
      # Description: Custom error handling for API responses
      exception_message = nil
      response_json = JSON.parse(response.body) rescue nil
      if response_json.is_a? Hash
        if response_json['errors'].is_a? Array
          response_errors = response_json['errors'].join(', ')
        elsif response_json['error']
          response_errors = response_json['error']
        end
        if response_errors
          exception_message = "#{response.status_message}: #{response_errors}"
        end
      end

      unless exception_message
        exception_message = "#{response.status_message}: [Could not parse errors from response body]"
      end

      fail ApiError.new(:code => response.code,
                        :response_headers => response.headers,
                        :response_body => response.body),
           exception_message
      # <--------------- END DOCSPRING CUSTOMIZATION ----------------->
    end
  end

  if opts[:return_type] == 'File'
    data = tempfile
  elsif opts[:return_type]
    data = deserialize(response, opts[:return_type])
  else
    data = nil
  end
  return data, response.code, response.headers
end

#convert_to_type(data, return_type) ⇒ Mixed

Convert data to the given return type.

Parameters:

  • data (Object)

    Data to be converted

  • return_type (String)

    Return type

Returns:

  • (Mixed)

    Data in a particular type



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/docspring/api_client.rb', line 271

def convert_to_type(data, return_type)
  return nil if data.nil?
  case return_type
  when 'String'
    data.to_s
  when 'Integer'
    data.to_i
  when 'Float'
    data.to_f
  when 'Boolean'
    data == true
  when 'Time'
    # parse date time (expecting ISO 8601 format)
    Time.parse data
  when 'Date'
    # parse date time (expecting ISO 8601 format)
    Date.parse data
  when 'Object'
    # generic object (usually a Hash), return directly
    data
  when /\AArray<(.+)>\z/
    # e.g. Array<Pet>
    sub_type = $1
    data.map { |item| convert_to_type(item, sub_type) }
  when /\AHash\<String, (.+)\>\z/
    # e.g. Hash<String, Integer>
    sub_type = $1
    {}.tap do |hash|
      data.each { |k, v| hash[k] = convert_to_type(v, sub_type) }
    end
  else
    # models (e.g. Pet) or oneOf
    klass = DocSpring.const_get(return_type)
    klass.respond_to?(:openapi_one_of) ? klass.build(data) : klass.build_from_hash(data)
  end
end

#deserialize(response, return_type) ⇒ Object

Deserialize the response to the given return type.

Parameters:

  • response (Response)

    HTTP response

  • return_type (String)

    some examples: “User”, “Array<User>”, “Hash<String, Integer>”



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/docspring/api_client.rb', line 242

def deserialize(response, return_type)
  body = response.body
  return nil if body.nil? || body.empty?

  # return response body directly for String return type
  return body.to_s if return_type == 'String'

  # ensuring a default content type
  content_type = response.headers['Content-Type'] || 'application/json'

  fail "Content-Type is not supported: #{content_type}" unless json_mime?(content_type)

  begin
    data = JSON.parse("[#{body}]", :symbolize_names => true)[0]
  rescue JSON::ParserError => e
    if %w(String Date Time).include?(return_type)
      data = body
    else
      raise e
    end
  end

  convert_to_type data, return_type
end

#download_file(request) ⇒ Tempfile

Save response body into a file in (the defined) temporary folder, using the filename from the “Content-Disposition” header if provided, otherwise a random filename. The response body is written to the file in chunks in order to handle files which size is larger than maximum Ruby String or even larger than the maximum memory a Ruby process can use.

Returns:

  • (Tempfile)

    the tempfile generated

See Also:



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/docspring/api_client.rb', line 192

def download_file(request)
  tempfile = nil
  encoding = nil
  request.on_headers do |response|
    content_disposition = response.headers['Content-Disposition']
    if content_disposition && content_disposition =~ /filename=/i
      filename = content_disposition[/filename=['"]?([^'"\s]+)['"]?/, 1]
      prefix = sanitize_filename(filename)
    else
      prefix = 'download-'
    end
    prefix = prefix + '-' unless prefix.end_with?('-')
    encoding = response.body.encoding
    tempfile = Tempfile.open(prefix, @config.temp_folder_path, encoding: encoding)
  end
  request.on_body do |chunk|
    chunk.force_encoding(encoding)
    tempfile.write(chunk)
  end
  # run the request to ensure the tempfile is created successfully before returning it
  request.run
  if tempfile
    tempfile.close
    @config.logger.info "Temp file written to #{tempfile.path}, please copy the file to a proper folder "\
                        "with e.g. `FileUtils.cp(tempfile.path, '/new/file/path')` otherwise the temp file "\
                        "will be deleted automatically with GC. It's also recommended to delete the temp file "\
                        "explicitly with `tempfile.delete`"
  else
    fail ApiError.new("Failed to create the tempfile based on the HTTP response from the server: #{request.inspect}") 
  end

  tempfile
end

#json_mime?(mime) ⇒ Boolean

Check if the given MIME is a JSON MIME. JSON MIME examples:

application/json
application/json; charset=UTF8
APPLICATION/JSON
*/*

Parameters:

  • mime (String)

    MIME

Returns:

  • (Boolean)

    True if the MIME is application/json



234
235
236
# File 'lib/docspring/api_client.rb', line 234

def json_mime?(mime)
  (mime == '*/*') || !(mime =~ /^Application\/.*json(?!p)(;.*)?/i).nil?
end

#object_to_hash(obj) ⇒ String

Convert object(non-array) to hash.

Parameters:

  • obj (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



386
387
388
389
390
391
392
# File 'lib/docspring/api_client.rb', line 386

def object_to_hash(obj)
  if obj.respond_to?(:to_hash)
    obj.to_hash
  else
    obj
  end
end

#object_to_http_body(model) ⇒ String

Convert object (array, hash, object, etc) to JSON string.

Parameters:

  • model (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



372
373
374
375
376
377
378
379
380
381
# File 'lib/docspring/api_client.rb', line 372

def object_to_http_body(model)
  return model if model.nil? || model.is_a?(String)
  local_body = nil
  if model.is_a?(Array)
    local_body = model.map { |m| object_to_hash(m) }
  else
    local_body = object_to_hash(model)
  end
  local_body.to_json
end

#sanitize_filename(filename) ⇒ String

Sanitize filename by removing path. e.g. ../../sun.gif becomes sun.gif

Parameters:

  • filename (String)

    the filename to be sanitized

Returns:

  • (String)

    the sanitized filename



313
314
315
# File 'lib/docspring/api_client.rb', line 313

def sanitize_filename(filename)
  filename.split(/[\/\\]/).last
end

#select_header_accept(accepts) ⇒ String

Return Accept header based on an array of accepts provided.

Parameters:

  • accepts (Array)

    array for Accept

Returns:

  • (String)

    the Accept header (e.g. application/json)



351
352
353
354
355
356
# File 'lib/docspring/api_client.rb', line 351

def select_header_accept(accepts)
  return nil if accepts.nil? || accepts.empty?
  # use JSON when present, otherwise use all of the provided
  json_accept = accepts.find { |s| json_mime?(s) }
  json_accept || accepts.join(',')
end

#select_header_content_type(content_types) ⇒ String

Return Content-Type header based on an array of content types provided.

Parameters:

  • content_types (Array)

    array for Content-Type

Returns:

  • (String)

    the Content-Type header (e.g. application/json)



361
362
363
364
365
366
367
# File 'lib/docspring/api_client.rb', line 361

def select_header_content_type(content_types)
  # return nil by default
  return if content_types.nil? || content_types.empty?
  # use JSON when present, otherwise use the first one
  json_content_type = content_types.find { |s| json_mime?(s) }
  json_content_type || content_types.first
end

#update_params_for_auth!(header_params, query_params, auth_names) ⇒ Object

Update header and query params based on authentication settings.

Parameters:

  • header_params (Hash)

    Header parameters

  • query_params (Hash)

    Query parameters

  • auth_names (String)

    Authentication scheme name



328
329
330
331
332
333
334
335
336
337
338
# File 'lib/docspring/api_client.rb', line 328

def update_params_for_auth!(header_params, query_params, auth_names)
  Array(auth_names).each do |auth_name|
    auth_setting = @config.auth_settings[auth_name]
    next unless auth_setting
    case auth_setting[:in]
    when 'header' then header_params[auth_setting[:key]] = auth_setting[:value]
    when 'query'  then query_params[auth_setting[:key]] = auth_setting[:value]
    else fail ArgumentError, 'Authentication token must be in `query` or `header`'
    end
  end
end

#user_agent=(user_agent) ⇒ Object

Sets user agent in HTTP header

Parameters:

  • user_agent (String)

    User agent (e.g. openapi-generator/ruby/1.0.0)



343
344
345
346
# File 'lib/docspring/api_client.rb', line 343

def user_agent=(user_agent)
  @user_agent = user_agent
  @default_headers['User-Agent'] = @user_agent
end