Class: DocSpring::CombinedSubmission
- Inherits:
-
Object
- Object
- DocSpring::CombinedSubmission
- Defined in:
- lib/docspring/models/combined_submission.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#actions ⇒ Object
Returns the value of attribute actions.
-
#download_url ⇒ Object
Returns the value of attribute download_url.
-
#error_message ⇒ Object
Returns the value of attribute error_message.
-
#expired ⇒ Object
Returns the value of attribute expired.
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#expires_in ⇒ Object
Returns the value of attribute expires_in.
-
#id ⇒ Object
Returns the value of attribute id.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#password ⇒ Object
Returns the value of attribute password.
-
#pdf_hash ⇒ Object
Returns the value of attribute pdf_hash.
-
#source_pdfs ⇒ Object
Returns the value of attribute source_pdfs.
-
#state ⇒ Object
Returns the value of attribute state.
-
#submission_ids ⇒ Object
Returns the value of attribute submission_ids.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CombinedSubmission
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CombinedSubmission
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/docspring/models/combined_submission.rb', line 123 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DocSpring::CombinedSubmission` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DocSpring::CombinedSubmission`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'expired') self.expired = attributes[:'expired'] else self.expired = nil end if attributes.key?(:'expires_in') self.expires_in = attributes[:'expires_in'] end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end if attributes.key?(:'state') self.state = attributes[:'state'] else self.state = nil end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'password') self.password = attributes[:'password'] end if attributes.key?(:'submission_ids') if (value = attributes[:'submission_ids']).is_a?(Array) self.submission_ids = value end else self.submission_ids = nil end if attributes.key?(:'source_pdfs') if (value = attributes[:'source_pdfs']).is_a?(Array) self.source_pdfs = value end else self.source_pdfs = nil end if attributes.key?(:'download_url') self.download_url = attributes[:'download_url'] end if attributes.key?(:'pdf_hash') self.pdf_hash = attributes[:'pdf_hash'] end if attributes.key?(:'actions') if (value = attributes[:'actions']).is_a?(Array) self.actions = value end end end |
Instance Attribute Details
#actions ⇒ Object
Returns the value of attribute actions.
42 43 44 |
# File 'lib/docspring/models/combined_submission.rb', line 42 def actions @actions end |
#download_url ⇒ Object
Returns the value of attribute download_url.
38 39 40 |
# File 'lib/docspring/models/combined_submission.rb', line 38 def download_url @download_url end |
#error_message ⇒ Object
Returns the value of attribute error_message.
28 29 30 |
# File 'lib/docspring/models/combined_submission.rb', line 28 def end |
#expired ⇒ Object
Returns the value of attribute expired.
20 21 22 |
# File 'lib/docspring/models/combined_submission.rb', line 20 def expired @expired end |
#expires_at ⇒ Object
Returns the value of attribute expires_at.
24 25 26 |
# File 'lib/docspring/models/combined_submission.rb', line 24 def expires_at @expires_at end |
#expires_in ⇒ Object
Returns the value of attribute expires_in.
22 23 24 |
# File 'lib/docspring/models/combined_submission.rb', line 22 def expires_in @expires_in end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/docspring/models/combined_submission.rb', line 18 def id @id end |
#metadata ⇒ Object
Returns the value of attribute metadata.
30 31 32 |
# File 'lib/docspring/models/combined_submission.rb', line 30 def end |
#password ⇒ Object
Returns the value of attribute password.
32 33 34 |
# File 'lib/docspring/models/combined_submission.rb', line 32 def password @password end |
#pdf_hash ⇒ Object
Returns the value of attribute pdf_hash.
40 41 42 |
# File 'lib/docspring/models/combined_submission.rb', line 40 def pdf_hash @pdf_hash end |
#source_pdfs ⇒ Object
Returns the value of attribute source_pdfs.
36 37 38 |
# File 'lib/docspring/models/combined_submission.rb', line 36 def source_pdfs @source_pdfs end |
#state ⇒ Object
Returns the value of attribute state.
26 27 28 |
# File 'lib/docspring/models/combined_submission.rb', line 26 def state @state end |
#submission_ids ⇒ Object
Returns the value of attribute submission_ids.
34 35 36 |
# File 'lib/docspring/models/combined_submission.rb', line 34 def submission_ids @submission_ids end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/docspring/models/combined_submission.rb', line 316 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = DocSpring.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/docspring/models/combined_submission.rb', line 86 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/docspring/models/combined_submission.rb', line 67 def self.attribute_map { :'id' => :'id', :'expired' => :'expired', :'expires_in' => :'expires_in', :'expires_at' => :'expires_at', :'state' => :'state', :'error_message' => :'error_message', :'metadata' => :'metadata', :'password' => :'password', :'submission_ids' => :'submission_ids', :'source_pdfs' => :'source_pdfs', :'download_url' => :'download_url', :'pdf_hash' => :'pdf_hash', :'actions' => :'actions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/docspring/models/combined_submission.rb', line 292 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
110 111 112 113 114 115 116 117 118 119 |
# File 'lib/docspring/models/combined_submission.rb', line 110 def self.openapi_nullable Set.new([ :'expires_in', :'expires_at', :'error_message', :'password', :'download_url', :'pdf_hash', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/docspring/models/combined_submission.rb', line 91 def self.openapi_types { :'id' => :'String', :'expired' => :'Boolean', :'expires_in' => :'Integer', :'expires_at' => :'String', :'state' => :'String', :'error_message' => :'String', :'metadata' => :'Object', :'password' => :'String', :'submission_ids' => :'Array<String>', :'source_pdfs' => :'Array<Object>', :'download_url' => :'String', :'pdf_hash' => :'String', :'actions' => :'Array<CombinedSubmissionAction>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/docspring/models/combined_submission.rb', line 259 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && expired == o.expired && expires_in == o.expires_in && expires_at == o.expires_at && state == o.state && == o. && == o. && password == o.password && submission_ids == o.submission_ids && source_pdfs == o.source_pdfs && download_url == o.download_url && pdf_hash == o.pdf_hash && actions == o.actions end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/docspring/models/combined_submission.rb', line 387 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
279 280 281 |
# File 'lib/docspring/models/combined_submission.rb', line 279 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
285 286 287 |
# File 'lib/docspring/models/combined_submission.rb', line 285 def hash [id, expired, expires_in, expires_at, state, , , password, submission_ids, source_pdfs, download_url, pdf_hash, actions].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/docspring/models/combined_submission.rb', line 207 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @expired.nil? invalid_properties.push('invalid value for "expired", expired cannot be nil.') end if @state.nil? invalid_properties.push('invalid value for "state", state cannot be nil.') end if @submission_ids.nil? invalid_properties.push('invalid value for "submission_ids", submission_ids cannot be nil.') end if @source_pdfs.nil? invalid_properties.push('invalid value for "source_pdfs", source_pdfs cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
363 364 365 |
# File 'lib/docspring/models/combined_submission.rb', line 363 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
369 370 371 372 373 374 375 376 377 378 379 380 381 |
# File 'lib/docspring/models/combined_submission.rb', line 369 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
357 358 359 |
# File 'lib/docspring/models/combined_submission.rb', line 357 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/docspring/models/combined_submission.rb', line 235 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @expired.nil? return false if @state.nil? state_validator = EnumAttributeValidator.new('String', ["pending", "processed", "error"]) return false unless state_validator.valid?(@state) return false if @submission_ids.nil? return false if @source_pdfs.nil? true end |