Class: DocSpring::PendingTemplate

Inherits:
Object
  • Object
show all
Defined in:
lib/docspring/models/pending_template.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PendingTemplate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/docspring/models/pending_template.rb', line 139

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DocSpring::PendingTemplate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DocSpring::PendingTemplate`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'template_type')
    self.template_type = attributes[:'template_type']
  else
    self.template_type = nil
  end

  if attributes.key?(:'public_web_form')
    self.public_web_form = attributes[:'public_web_form']
  else
    self.public_web_form = nil
  end

  if attributes.key?(:'public_submissions')
    self.public_submissions = attributes[:'public_submissions']
  else
    self.public_submissions = nil
  end

  if attributes.key?(:'expire_submissions')
    self.expire_submissions = attributes[:'expire_submissions']
  else
    self.expire_submissions = nil
  end

  if attributes.key?(:'expire_after')
    self.expire_after = attributes[:'expire_after']
  end

  if attributes.key?(:'locked')
    self.locked = attributes[:'locked']
  else
    self.locked = nil
  end

  if attributes.key?(:'expiration_interval')
    self.expiration_interval = attributes[:'expiration_interval']
  end

  if attributes.key?(:'allow_additional_properties')
    self.allow_additional_properties = attributes[:'allow_additional_properties']
  else
    self.allow_additional_properties = nil
  end

  if attributes.key?(:'editable_submissions')
    self.editable_submissions = attributes[:'editable_submissions']
  else
    self.editable_submissions = nil
  end

  if attributes.key?(:'webhook_url')
    self.webhook_url = attributes[:'webhook_url']
  else
    self.webhook_url = nil
  end

  if attributes.key?(:'slack_webhook_url')
    self.slack_webhook_url = attributes[:'slack_webhook_url']
  else
    self.slack_webhook_url = nil
  end

  if attributes.key?(:'redirect_url')
    self.redirect_url = attributes[:'redirect_url']
  else
    self.redirect_url = nil
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  end

  if attributes.key?(:'parent_folder_id')
    self.parent_folder_id = attributes[:'parent_folder_id']
  end
end

Instance Attribute Details

#allow_additional_propertiesObject

Returns the value of attribute allow_additional_properties.



38
39
40
# File 'lib/docspring/models/pending_template.rb', line 38

def allow_additional_properties
  @allow_additional_properties
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/docspring/models/pending_template.rb', line 22

def description
  @description
end

#editable_submissionsObject

Returns the value of attribute editable_submissions.



40
41
42
# File 'lib/docspring/models/pending_template.rb', line 40

def editable_submissions
  @editable_submissions
end

#expiration_intervalObject

Returns the value of attribute expiration_interval.



36
37
38
# File 'lib/docspring/models/pending_template.rb', line 36

def expiration_interval
  @expiration_interval
end

#expire_afterObject

Returns the value of attribute expire_after.



32
33
34
# File 'lib/docspring/models/pending_template.rb', line 32

def expire_after
  @expire_after
end

#expire_submissionsObject

Returns the value of attribute expire_submissions.



30
31
32
# File 'lib/docspring/models/pending_template.rb', line 30

def expire_submissions
  @expire_submissions
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/docspring/models/pending_template.rb', line 18

def id
  @id
end

#lockedObject

Returns the value of attribute locked.



34
35
36
# File 'lib/docspring/models/pending_template.rb', line 34

def locked
  @locked
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/docspring/models/pending_template.rb', line 20

def name
  @name
end

#parent_folder_idObject

Returns the value of attribute parent_folder_id.



50
51
52
# File 'lib/docspring/models/pending_template.rb', line 50

def parent_folder_id
  @parent_folder_id
end

#pathObject

Returns the value of attribute path.



48
49
50
# File 'lib/docspring/models/pending_template.rb', line 48

def path
  @path
end

#public_submissionsObject

Returns the value of attribute public_submissions.



28
29
30
# File 'lib/docspring/models/pending_template.rb', line 28

def public_submissions
  @public_submissions
end

#public_web_formObject

Returns the value of attribute public_web_form.



26
27
28
# File 'lib/docspring/models/pending_template.rb', line 26

def public_web_form
  @public_web_form
end

#redirect_urlObject

Returns the value of attribute redirect_url.



46
47
48
# File 'lib/docspring/models/pending_template.rb', line 46

def redirect_url
  @redirect_url
end

#slack_webhook_urlObject

Returns the value of attribute slack_webhook_url.



44
45
46
# File 'lib/docspring/models/pending_template.rb', line 44

def slack_webhook_url
  @slack_webhook_url
end

#template_typeObject

Returns the value of attribute template_type.



24
25
26
# File 'lib/docspring/models/pending_template.rb', line 24

def template_type
  @template_type
end

#webhook_urlObject

Returns the value of attribute webhook_url.



42
43
44
# File 'lib/docspring/models/pending_template.rb', line 42

def webhook_url
  @webhook_url
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/docspring/models/pending_template.rb', line 377

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = DocSpring.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/docspring/models/pending_template.rb', line 98

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/docspring/models/pending_template.rb', line 75

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'template_type' => :'template_type',
    :'public_web_form' => :'public_web_form',
    :'public_submissions' => :'public_submissions',
    :'expire_submissions' => :'expire_submissions',
    :'expire_after' => :'expire_after',
    :'locked' => :'locked',
    :'expiration_interval' => :'expiration_interval',
    :'allow_additional_properties' => :'allow_additional_properties',
    :'editable_submissions' => :'editable_submissions',
    :'webhook_url' => :'webhook_url',
    :'slack_webhook_url' => :'slack_webhook_url',
    :'redirect_url' => :'redirect_url',
    :'path' => :'path',
    :'parent_folder_id' => :'parent_folder_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/docspring/models/pending_template.rb', line 353

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



126
127
128
129
130
131
132
133
134
135
# File 'lib/docspring/models/pending_template.rb', line 126

def self.openapi_nullable
  Set.new([
    :'name',
    :'description',
    :'webhook_url',
    :'slack_webhook_url',
    :'redirect_url',
    :'parent_folder_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/docspring/models/pending_template.rb', line 103

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'template_type' => :'String',
    :'public_web_form' => :'Boolean',
    :'public_submissions' => :'Boolean',
    :'expire_submissions' => :'Boolean',
    :'expire_after' => :'Float',
    :'locked' => :'Boolean',
    :'expiration_interval' => :'String',
    :'allow_additional_properties' => :'Boolean',
    :'editable_submissions' => :'Boolean',
    :'webhook_url' => :'String',
    :'slack_webhook_url' => :'String',
    :'redirect_url' => :'String',
    :'path' => :'String',
    :'parent_folder_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/docspring/models/pending_template.rb', line 316

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      template_type == o.template_type &&
      public_web_form == o.public_web_form &&
      public_submissions == o.public_submissions &&
      expire_submissions == o.expire_submissions &&
      expire_after == o.expire_after &&
      locked == o.locked &&
      expiration_interval == o.expiration_interval &&
      allow_additional_properties == o.allow_additional_properties &&
      editable_submissions == o.editable_submissions &&
      webhook_url == o.webhook_url &&
      slack_webhook_url == o.slack_webhook_url &&
      redirect_url == o.redirect_url &&
      path == o.path &&
      parent_folder_id == o.parent_folder_id
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



448
449
450
451
452
453
454
455
456
457
458
459
460
# File 'lib/docspring/models/pending_template.rb', line 448

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


340
341
342
# File 'lib/docspring/models/pending_template.rb', line 340

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



346
347
348
# File 'lib/docspring/models/pending_template.rb', line 346

def hash
  [id, name, description, template_type, public_web_form, public_submissions, expire_submissions, expire_after, locked, expiration_interval, allow_additional_properties, editable_submissions, webhook_url, slack_webhook_url, redirect_url, path, parent_folder_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/docspring/models/pending_template.rb', line 249

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @template_type.nil?
    invalid_properties.push('invalid value for "template_type", template_type cannot be nil.')
  end

  if @public_web_form.nil?
    invalid_properties.push('invalid value for "public_web_form", public_web_form cannot be nil.')
  end

  if @public_submissions.nil?
    invalid_properties.push('invalid value for "public_submissions", public_submissions cannot be nil.')
  end

  if @expire_submissions.nil?
    invalid_properties.push('invalid value for "expire_submissions", expire_submissions cannot be nil.')
  end

  if @locked.nil?
    invalid_properties.push('invalid value for "locked", locked cannot be nil.')
  end

  if @allow_additional_properties.nil?
    invalid_properties.push('invalid value for "allow_additional_properties", allow_additional_properties cannot be nil.')
  end

  if @editable_submissions.nil?
    invalid_properties.push('invalid value for "editable_submissions", editable_submissions cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



424
425
426
# File 'lib/docspring/models/pending_template.rb', line 424

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/docspring/models/pending_template.rb', line 430

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



418
419
420
# File 'lib/docspring/models/pending_template.rb', line 418

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/docspring/models/pending_template.rb', line 289

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @template_type.nil?
  return false if @public_web_form.nil?
  return false if @public_submissions.nil?
  return false if @expire_submissions.nil?
  return false if @locked.nil?
  expiration_interval_validator = EnumAttributeValidator.new('String', ["minutes", "hours", "days"])
  return false unless expiration_interval_validator.valid?(@expiration_interval)
  return false if @allow_additional_properties.nil?
  return false if @editable_submissions.nil?
  true
end