Class: DocSpring::Submission

Inherits:
Object
  • Object
show all
Defined in:
lib/docspring/models/submission.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Submission

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/docspring/models/submission.rb', line 151

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DocSpring::Submission` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DocSpring::Submission`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  end

  if attributes.key?(:'test')
    self.test = attributes[:'test']
  else
    self.test = nil
  end

  if attributes.key?(:'editable')
    self.editable = attributes[:'editable']
  end

  if attributes.key?(:'expired')
    self.expired = attributes[:'expired']
  else
    self.expired = nil
  end

  if attributes.key?(:'expires_at')
    self.expires_at = attributes[:'expires_at']
  end

  if attributes.key?(:'processed_at')
    self.processed_at = attributes[:'processed_at']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  else
    self.state = nil
  end

  if attributes.key?(:'data')
    self.data = attributes[:'data']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'truncated_text')
    self.truncated_text = attributes[:'truncated_text']
  end

  if attributes.key?(:'pdf_hash')
    self.pdf_hash = attributes[:'pdf_hash']
  end

  if attributes.key?(:'download_url')
    self.download_url = attributes[:'download_url']
  end

  if attributes.key?(:'permanent_download_url')
    self.permanent_download_url = attributes[:'permanent_download_url']
  end

  if attributes.key?(:'batch_id')
    self.batch_id = attributes[:'batch_id']
  end

  if attributes.key?(:'data_requests')
    if (value = attributes[:'data_requests']).is_a?(Array)
      self.data_requests = value
    end
  end

  if attributes.key?(:'actions')
    if (value = attributes[:'actions']).is_a?(Array)
      self.actions = value
    end
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'referrer')
    self.referrer = attributes[:'referrer']
  end
end

Instance Attribute Details

#actionsObject

Returns the value of attribute actions.



50
51
52
# File 'lib/docspring/models/submission.rb', line 50

def actions
  @actions
end

#batch_idObject

Returns the value of attribute batch_id.



46
47
48
# File 'lib/docspring/models/submission.rb', line 46

def batch_id
  @batch_id
end

#dataObject

Returns the value of attribute data.



34
35
36
# File 'lib/docspring/models/submission.rb', line 34

def data
  @data
end

#data_requestsObject

Returns the value of attribute data_requests.



48
49
50
# File 'lib/docspring/models/submission.rb', line 48

def data_requests
  @data_requests
end

#download_urlObject

Returns the value of attribute download_url.



42
43
44
# File 'lib/docspring/models/submission.rb', line 42

def download_url
  @download_url
end

#editableObject

Returns the value of attribute editable.



24
25
26
# File 'lib/docspring/models/submission.rb', line 24

def editable
  @editable
end

#expiredObject

Returns the value of attribute expired.



26
27
28
# File 'lib/docspring/models/submission.rb', line 26

def expired
  @expired
end

#expires_atObject

Returns the value of attribute expires_at.



28
29
30
# File 'lib/docspring/models/submission.rb', line 28

def expires_at
  @expires_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/docspring/models/submission.rb', line 18

def id
  @id
end

#metadataObject

Returns the value of attribute metadata.



36
37
38
# File 'lib/docspring/models/submission.rb', line 36

def 
  @metadata
end

#pdf_hashObject

Returns the value of attribute pdf_hash.



40
41
42
# File 'lib/docspring/models/submission.rb', line 40

def pdf_hash
  @pdf_hash
end

#permanent_download_urlObject

Returns the value of attribute permanent_download_url.



44
45
46
# File 'lib/docspring/models/submission.rb', line 44

def permanent_download_url
  @permanent_download_url
end

#processed_atObject

Returns the value of attribute processed_at.



30
31
32
# File 'lib/docspring/models/submission.rb', line 30

def processed_at
  @processed_at
end

#referrerObject

Returns the value of attribute referrer.



54
55
56
# File 'lib/docspring/models/submission.rb', line 54

def referrer
  @referrer
end

#sourceObject

Returns the value of attribute source.



52
53
54
# File 'lib/docspring/models/submission.rb', line 52

def source
  @source
end

#stateObject

Returns the value of attribute state.



32
33
34
# File 'lib/docspring/models/submission.rb', line 32

def state
  @state
end

#template_idObject

Returns the value of attribute template_id.



20
21
22
# File 'lib/docspring/models/submission.rb', line 20

def template_id
  @template_id
end

#testObject

Returns the value of attribute test.



22
23
24
# File 'lib/docspring/models/submission.rb', line 22

def test
  @test
end

#truncated_textObject

Returns the value of attribute truncated_text.



38
39
40
# File 'lib/docspring/models/submission.rb', line 38

def truncated_text
  @truncated_text
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/docspring/models/submission.rb', line 365

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = DocSpring.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



104
105
106
# File 'lib/docspring/models/submission.rb', line 104

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/docspring/models/submission.rb', line 79

def self.attribute_map
  {
    :'id' => :'id',
    :'template_id' => :'template_id',
    :'test' => :'test',
    :'editable' => :'editable',
    :'expired' => :'expired',
    :'expires_at' => :'expires_at',
    :'processed_at' => :'processed_at',
    :'state' => :'state',
    :'data' => :'data',
    :'metadata' => :'metadata',
    :'truncated_text' => :'truncated_text',
    :'pdf_hash' => :'pdf_hash',
    :'download_url' => :'download_url',
    :'permanent_download_url' => :'permanent_download_url',
    :'batch_id' => :'batch_id',
    :'data_requests' => :'data_requests',
    :'actions' => :'actions',
    :'source' => :'source',
    :'referrer' => :'referrer'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/docspring/models/submission.rb', line 341

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/docspring/models/submission.rb', line 134

def self.openapi_nullable
  Set.new([
    :'editable',
    :'expires_at',
    :'processed_at',
    :'data',
    :'pdf_hash',
    :'download_url',
    :'permanent_download_url',
    :'batch_id',
    :'source',
    :'referrer'
  ])
end

.openapi_typesObject

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/docspring/models/submission.rb', line 109

def self.openapi_types
  {
    :'id' => :'String',
    :'template_id' => :'String',
    :'test' => :'Boolean',
    :'editable' => :'Boolean',
    :'expired' => :'Boolean',
    :'expires_at' => :'String',
    :'processed_at' => :'String',
    :'state' => :'String',
    :'data' => :'Object',
    :'metadata' => :'Object',
    :'truncated_text' => :'Object',
    :'pdf_hash' => :'String',
    :'download_url' => :'String',
    :'permanent_download_url' => :'String',
    :'batch_id' => :'String',
    :'data_requests' => :'Array<SubmissionDataRequest>',
    :'actions' => :'Array<SubmissionAction>',
    :'source' => :'String',
    :'referrer' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/docspring/models/submission.rb', line 302

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      template_id == o.template_id &&
      test == o.test &&
      editable == o.editable &&
      expired == o.expired &&
      expires_at == o.expires_at &&
      processed_at == o.processed_at &&
      state == o.state &&
      data == o.data &&
       == o. &&
      truncated_text == o.truncated_text &&
      pdf_hash == o.pdf_hash &&
      download_url == o.download_url &&
      permanent_download_url == o.permanent_download_url &&
      batch_id == o.batch_id &&
      data_requests == o.data_requests &&
      actions == o.actions &&
      source == o.source &&
      referrer == o.referrer
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/docspring/models/submission.rb', line 436

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


328
329
330
# File 'lib/docspring/models/submission.rb', line 328

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



334
335
336
# File 'lib/docspring/models/submission.rb', line 334

def hash
  [id, template_id, test, editable, expired, expires_at, processed_at, state, data, , truncated_text, pdf_hash, download_url, permanent_download_url, batch_id, data_requests, actions, source, referrer].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/docspring/models/submission.rb', line 255

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @test.nil?
    invalid_properties.push('invalid value for "test", test cannot be nil.')
  end

  if @expired.nil?
    invalid_properties.push('invalid value for "expired", expired cannot be nil.')
  end

  if @state.nil?
    invalid_properties.push('invalid value for "state", state cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



412
413
414
# File 'lib/docspring/models/submission.rb', line 412

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/docspring/models/submission.rb', line 418

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



406
407
408
# File 'lib/docspring/models/submission.rb', line 406

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



279
280
281
282
283
284
285
286
287
288
# File 'lib/docspring/models/submission.rb', line 279

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @test.nil?
  return false if @expired.nil?
  return false if @state.nil?
  state_validator = EnumAttributeValidator.new('String', ["pending", "processed", "invalid_data", "error", "image_download_failed", "image_processing_failed", "waiting_for_data_requests", "syntax_error", "account_suspended", "license_revoked", "accidental"])
  return false unless state_validator.valid?(@state)
  true
end