Class: DocSpring::UpdateSubmissionDataRequestData
- Inherits:
-
Object
- Object
- DocSpring::UpdateSubmissionDataRequestData
- Defined in:
- lib/docspring/models/update_submission_data_request_data.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#auth_phone_number_hash ⇒ Object
Returns the value of attribute auth_phone_number_hash.
-
#auth_provider ⇒ Object
Returns the value of attribute auth_provider.
-
#auth_second_factor_type ⇒ Object
Returns the value of attribute auth_second_factor_type.
-
#auth_session_id_hash ⇒ Object
Returns the value of attribute auth_session_id_hash.
-
#auth_session_started_at ⇒ Object
Returns the value of attribute auth_session_started_at.
-
#auth_type ⇒ Object
Returns the value of attribute auth_type.
-
#auth_user_id_hash ⇒ Object
Returns the value of attribute auth_user_id_hash.
-
#auth_username_hash ⇒ Object
Returns the value of attribute auth_username_hash.
-
#email ⇒ Object
Returns the value of attribute email.
-
#fields ⇒ Object
Returns the value of attribute fields.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#name ⇒ Object
Returns the value of attribute name.
-
#order ⇒ Object
Returns the value of attribute order.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateSubmissionDataRequestData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ UpdateSubmissionDataRequestData
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 125 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DocSpring::UpdateSubmissionDataRequestData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DocSpring::UpdateSubmissionDataRequestData`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'auth_phone_number_hash') self.auth_phone_number_hash = attributes[:'auth_phone_number_hash'] end if attributes.key?(:'auth_provider') self.auth_provider = attributes[:'auth_provider'] end if attributes.key?(:'auth_second_factor_type') self.auth_second_factor_type = attributes[:'auth_second_factor_type'] end if attributes.key?(:'auth_session_id_hash') self.auth_session_id_hash = attributes[:'auth_session_id_hash'] end if attributes.key?(:'auth_session_started_at') self.auth_session_started_at = attributes[:'auth_session_started_at'] end if attributes.key?(:'auth_type') self.auth_type = attributes[:'auth_type'] end if attributes.key?(:'auth_user_id_hash') self.auth_user_id_hash = attributes[:'auth_user_id_hash'] end if attributes.key?(:'auth_username_hash') self.auth_username_hash = attributes[:'auth_username_hash'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'fields') if (value = attributes[:'fields']).is_a?(Array) self.fields = value end end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'order') self.order = attributes[:'order'] end end |
Instance Attribute Details
#auth_phone_number_hash ⇒ Object
Returns the value of attribute auth_phone_number_hash.
18 19 20 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 18 def auth_phone_number_hash @auth_phone_number_hash end |
#auth_provider ⇒ Object
Returns the value of attribute auth_provider.
20 21 22 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 20 def auth_provider @auth_provider end |
#auth_second_factor_type ⇒ Object
Returns the value of attribute auth_second_factor_type.
22 23 24 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 22 def auth_second_factor_type @auth_second_factor_type end |
#auth_session_id_hash ⇒ Object
Returns the value of attribute auth_session_id_hash.
24 25 26 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 24 def auth_session_id_hash @auth_session_id_hash end |
#auth_session_started_at ⇒ Object
Returns the value of attribute auth_session_started_at.
26 27 28 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 26 def auth_session_started_at @auth_session_started_at end |
#auth_type ⇒ Object
Returns the value of attribute auth_type.
28 29 30 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 28 def auth_type @auth_type end |
#auth_user_id_hash ⇒ Object
Returns the value of attribute auth_user_id_hash.
30 31 32 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 30 def auth_user_id_hash @auth_user_id_hash end |
#auth_username_hash ⇒ Object
Returns the value of attribute auth_username_hash.
32 33 34 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 32 def auth_username_hash @auth_username_hash end |
#email ⇒ Object
Returns the value of attribute email.
34 35 36 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 34 def email @email end |
#fields ⇒ Object
Returns the value of attribute fields.
36 37 38 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 36 def fields @fields end |
#metadata ⇒ Object
Returns the value of attribute metadata.
38 39 40 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 38 def end |
#name ⇒ Object
Returns the value of attribute name.
40 41 42 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 40 def name @name end |
#order ⇒ Object
Returns the value of attribute order.
42 43 44 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 42 def order @order end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 291 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = DocSpring.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 86 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 67 def self.attribute_map { :'auth_phone_number_hash' => :'auth_phone_number_hash', :'auth_provider' => :'auth_provider', :'auth_second_factor_type' => :'auth_second_factor_type', :'auth_session_id_hash' => :'auth_session_id_hash', :'auth_session_started_at' => :'auth_session_started_at', :'auth_type' => :'auth_type', :'auth_user_id_hash' => :'auth_user_id_hash', :'auth_username_hash' => :'auth_username_hash', :'email' => :'email', :'fields' => :'fields', :'metadata' => :'metadata', :'name' => :'name', :'order' => :'order' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 267 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 110 def self.openapi_nullable Set.new([ :'auth_phone_number_hash', :'auth_provider', :'auth_session_id_hash', :'auth_session_started_at', :'auth_user_id_hash', :'auth_username_hash', :'email', :'name', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 91 def self.openapi_types { :'auth_phone_number_hash' => :'String', :'auth_provider' => :'String', :'auth_second_factor_type' => :'String', :'auth_session_id_hash' => :'String', :'auth_session_started_at' => :'String', :'auth_type' => :'String', :'auth_user_id_hash' => :'String', :'auth_username_hash' => :'String', :'email' => :'String', :'fields' => :'Array<String>', :'metadata' => :'Object', :'name' => :'String', :'order' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 234 def ==(o) return true if self.equal?(o) self.class == o.class && auth_phone_number_hash == o.auth_phone_number_hash && auth_provider == o.auth_provider && auth_second_factor_type == o.auth_second_factor_type && auth_session_id_hash == o.auth_session_id_hash && auth_session_started_at == o.auth_session_started_at && auth_type == o.auth_type && auth_user_id_hash == o.auth_user_id_hash && auth_username_hash == o.auth_username_hash && email == o.email && fields == o.fields && == o. && name == o.name && order == o.order end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 362 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
254 255 256 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 254 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
260 261 262 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 260 def hash [auth_phone_number_hash, auth_provider, auth_second_factor_type, auth_session_id_hash, auth_session_started_at, auth_type, auth_user_id_hash, auth_username_hash, email, fields, , name, order].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 199 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 195 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
338 339 340 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 338 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 344 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
332 333 334 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 332 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 207 208 209 210 |
# File 'lib/docspring/models/update_submission_data_request_data.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' auth_second_factor_type_validator = EnumAttributeValidator.new('String', ["none", "phone_number", "totp", "mobile_push", "security_key", "fingerprint"]) return false unless auth_second_factor_type_validator.valid?(@auth_second_factor_type) auth_type_validator = EnumAttributeValidator.new('String', ["none", "password", "oauth", "email_link", "phone_number", "ldap", "saml"]) return false unless auth_type_validator.valid?(@auth_type) true end |