Class: DocSpring::Configuration
- Inherits:
-
Object
- Object
- DocSpring::Configuration
- Defined in:
- lib/docspring/configuration.rb
Constant Summary collapse
- SCHEME_REGEX =
<————— BEGIN DOCSPRING CUSTOMIZATION —————–> Description: Add SCHEME_REGEX constant to extract scheme from host
/^(https?):\/\//
Instance Attribute Summary collapse
-
#access_token ⇒ Object
Defines the access token (Bearer) used with OAuth2.
-
#access_token_getter ⇒ Proc
Defines a Proc used to fetch or refresh access tokens (Bearer) used with OAuth2.
-
#api_key ⇒ Hash
Defines API keys used with API Key authentications.
-
#api_key_prefix ⇒ Hash
Defines API key prefixes used with API Key authentications.
-
#base_path ⇒ Object
Defines url base path.
-
#cert_file ⇒ Object
TLS/SSL setting Client certificate file (for client certificate).
-
#client_side_validation ⇒ true, false
Set this to false to skip client side validation in the operation.
-
#debugging ⇒ true, false
Set this to enable/disable debugging.
-
#force_ending_format ⇒ Object
Returns the value of attribute force_ending_format.
-
#host ⇒ Object
Defines url host.
-
#ignore_operation_servers ⇒ true, false
Set this to ignore operation servers for the API client.
-
#inject_format ⇒ Object
Returns the value of attribute inject_format.
-
#key_file ⇒ Object
TLS/SSL setting Client private key file (for client certificate).
-
#logger ⇒ #debug
Defines the logger used for debugging.
-
#params_encoding ⇒ Object
Set this to customize parameters encoding of array parameter with multi collectionFormat.
-
#password ⇒ String
(also: #api_token_secret)
Defines the password used with HTTP basic authentication.
-
#return_binary_data ⇒ Object
Set this to return data as binary instead of downloading a temp file.
-
#scheme ⇒ Object
Defines url scheme.
-
#server_index ⇒ Object
Define server configuration index.
-
#server_operation_index ⇒ Object
Define server operation configuration index.
-
#server_operation_variables ⇒ Object
Default server operation variables.
-
#server_variables ⇒ Object
Default server variables.
-
#ssl_ca_cert ⇒ String
TLS/SSL setting Set this to customize the certificate file to verify the peer.
-
#temp_folder_path ⇒ String
Defines the temporary folder to store downloaded files (for API endpoints that have file response).
-
#timeout ⇒ Object
The time limit for HTTP request in seconds.
-
#username ⇒ String
(also: #api_token_id)
<————— BEGIN DOCSPRING CUSTOMIZATION —————–> Description: Note that we also add a getter/setter for api_token_id and api_token_secret, aliases for username and password.
-
#verify_ssl ⇒ true, false
TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server.
-
#verify_ssl_host ⇒ true, false
TLS/SSL setting Set this to false to skip verifying SSL host name Default to true.
Class Method Summary collapse
-
.default ⇒ Object
The default Configuration object.
Instance Method Summary collapse
-
#access_token_with_refresh ⇒ Object
Gets access_token using access_token_getter or uses the static access_token.
-
#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object
Gets API key (with prefix if set).
-
#api_token_id=(api_token_id) ⇒ Object
<————— BEGIN DOCSPRING CUSTOMIZATION —————–> Description: Add getter/setter for api_token_id and api_token_secret, aliases for username and password.
- #api_token_secret=(api_token_secret) ⇒ Object
-
#auth_settings ⇒ Object
Returns Auth Settings hash for api client.
-
#base_url(operation = nil) ⇒ Object
Returns base URL for specified operation based on server settings.
-
#basic_auth_token ⇒ Object
Gets Basic Auth token string.
- #configure {|_self| ... } ⇒ Object
-
#initialize {|_self| ... } ⇒ Configuration
constructor
A new instance of Configuration.
- #operation_server_settings ⇒ Object
-
#server_settings ⇒ Object
Returns an array of Server setting.
-
#server_url(index, variables = {}, servers = nil) ⇒ Object
Returns URL based on server settings.
Constructor Details
#initialize {|_self| ... } ⇒ Configuration
Returns a new instance of Configuration.
168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/docspring/configuration.rb', line 168 def initialize @scheme = 'https' @host = 'api.docspring.com' @base_path = '/api/v1' @server_index = nil @server_operation_index = {} @server_variables = {} @server_operation_variables = {} @api_key = {} @api_key_prefix = {} @client_side_validation = true @verify_ssl = true @verify_ssl_host = true @cert_file = nil @key_file = nil @timeout = 0 @params_encoding = nil @debugging = false @ignore_operation_servers = false @inject_format = false @force_ending_format = false @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT) # <--------------- BEGIN DOCSPRING CUSTOMIZATION -----------------> # Description: Use ENV variables by default if they are provided. @username = ENV['DOCSPRING_TOKEN_ID'] @password = ENV['DOCSPRING_TOKEN_SECRET'] # <--------------- END DOCSPRING CUSTOMIZATION -----------------> yield(self) if block_given? end |
Instance Attribute Details
#access_token ⇒ Object
Defines the access token (Bearer) used with OAuth2.
72 73 74 |
# File 'lib/docspring/configuration.rb', line 72 def access_token @access_token end |
#access_token_getter ⇒ Proc
Defines a Proc used to fetch or refresh access tokens (Bearer) used with OAuth2. Overrides the access_token if set
77 78 79 |
# File 'lib/docspring/configuration.rb', line 77 def access_token_getter @access_token_getter end |
#api_key ⇒ Hash
Defines API keys used with API Key authentications.
47 48 49 |
# File 'lib/docspring/configuration.rb', line 47 def api_key @api_key end |
#api_key_prefix ⇒ Hash
Defines API key prefixes used with API Key authentications.
55 56 57 |
# File 'lib/docspring/configuration.rb', line 55 def api_key_prefix @api_key_prefix end |
#base_path ⇒ Object
Defines url base path
27 28 29 |
# File 'lib/docspring/configuration.rb', line 27 def base_path @base_path end |
#cert_file ⇒ Object
TLS/SSL setting Client certificate file (for client certificate)
150 151 152 |
# File 'lib/docspring/configuration.rb', line 150 def cert_file @cert_file end |
#client_side_validation ⇒ true, false
Set this to false to skip client side validation in the operation. Default to true.
119 120 121 |
# File 'lib/docspring/configuration.rb', line 119 def client_side_validation @client_side_validation end |
#debugging ⇒ true, false
Set this to enable/disable debugging. When enabled (set to true), HTTP request/response details will be logged with logger.debug (see the logger attribute). Default to false.
89 90 91 |
# File 'lib/docspring/configuration.rb', line 89 def debugging @debugging end |
#force_ending_format ⇒ Object
Returns the value of attribute force_ending_format.
166 167 168 |
# File 'lib/docspring/configuration.rb', line 166 def force_ending_format @force_ending_format end |
#host ⇒ Object
Defines url host
24 25 26 |
# File 'lib/docspring/configuration.rb', line 24 def host @host end |
#ignore_operation_servers ⇒ true, false
Set this to ignore operation servers for the API client. This is useful when you need to send requests to a different server than the one specified in the OpenAPI document. Will default to the base url defined in the spec but can be overridden by setting scheme, host, base_path directly. Default to false.
97 98 99 |
# File 'lib/docspring/configuration.rb', line 97 def ignore_operation_servers @ignore_operation_servers end |
#inject_format ⇒ Object
Returns the value of attribute inject_format.
164 165 166 |
# File 'lib/docspring/configuration.rb', line 164 def inject_format @inject_format end |
#key_file ⇒ Object
TLS/SSL setting Client private key file (for client certificate)
154 155 156 |
# File 'lib/docspring/configuration.rb', line 154 def key_file @key_file end |
#logger ⇒ #debug
Defines the logger used for debugging. Default to Rails.logger (when in Rails) or logging to STDOUT.
103 104 105 |
# File 'lib/docspring/configuration.rb', line 103 def logger @logger end |
#params_encoding ⇒ Object
Set this to customize parameters encoding of array parameter with multi collectionFormat. Default to nil.
github.com/typhoeus/ethon/blob/master/lib/ethon/easy/queryable.rb#L96
161 162 163 |
# File 'lib/docspring/configuration.rb', line 161 def params_encoding @params_encoding end |
#password ⇒ String Also known as: api_token_secret
Defines the password used with HTTP basic authentication.
69 70 71 |
# File 'lib/docspring/configuration.rb', line 69 def password @password end |
#return_binary_data ⇒ Object
Set this to return data as binary instead of downloading a temp file. When enabled (set to true) HTTP responses with return type File will be returned as a stream of binary data. Default to false.
82 83 84 |
# File 'lib/docspring/configuration.rb', line 82 def return_binary_data @return_binary_data end |
#scheme ⇒ Object
Defines url scheme
21 22 23 |
# File 'lib/docspring/configuration.rb', line 21 def scheme @scheme end |
#server_index ⇒ Object
Define server configuration index
30 31 32 |
# File 'lib/docspring/configuration.rb', line 30 def server_index @server_index end |
#server_operation_index ⇒ Object
Define server operation configuration index
33 34 35 |
# File 'lib/docspring/configuration.rb', line 33 def server_operation_index @server_operation_index end |
#server_operation_variables ⇒ Object
Default server operation variables
39 40 41 |
# File 'lib/docspring/configuration.rb', line 39 def server_operation_variables @server_operation_variables end |
#server_variables ⇒ Object
Default server variables
36 37 38 |
# File 'lib/docspring/configuration.rb', line 36 def server_variables @server_variables end |
#ssl_ca_cert ⇒ String
TLS/SSL setting Set this to customize the certificate file to verify the peer.
github.com/typhoeus/typhoeus/blob/master/lib/typhoeus/easy_factory.rb#L145
146 147 148 |
# File 'lib/docspring/configuration.rb', line 146 def ssl_ca_cert @ssl_ca_cert end |
#temp_folder_path ⇒ String
Defines the temporary folder to store downloaded files (for API endpoints that have file response). Default to use Tempfile.
110 111 112 |
# File 'lib/docspring/configuration.rb', line 110 def temp_folder_path @temp_folder_path end |
#timeout ⇒ Object
The time limit for HTTP request in seconds. Default to 0 (never times out).
114 115 116 |
# File 'lib/docspring/configuration.rb', line 114 def timeout @timeout end |
#username ⇒ String Also known as: api_token_id
<————— BEGIN DOCSPRING CUSTOMIZATION —————–> Description: Note that we also add a getter/setter for api_token_id and api_token_secret, aliases for username and password. <————— END DOCSPRING CUSTOMIZATION —————–> Defines the username used with HTTP basic authentication.
64 65 66 |
# File 'lib/docspring/configuration.rb', line 64 def username @username end |
#verify_ssl ⇒ true, false
Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.
TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server. Default to true.
128 129 130 |
# File 'lib/docspring/configuration.rb', line 128 def verify_ssl @verify_ssl end |
#verify_ssl_host ⇒ true, false
Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.
TLS/SSL setting Set this to false to skip verifying SSL host name Default to true.
137 138 139 |
# File 'lib/docspring/configuration.rb', line 137 def verify_ssl_host @verify_ssl_host end |
Class Method Details
.default ⇒ Object
The default Configuration object.
214 215 216 |
# File 'lib/docspring/configuration.rb', line 214 def self.default @@default ||= Configuration.new end |
Instance Method Details
#access_token_with_refresh ⇒ Object
Gets access_token using access_token_getter or uses the static access_token
266 267 268 269 |
# File 'lib/docspring/configuration.rb', line 266 def access_token_with_refresh return access_token if access_token_getter.nil? access_token_getter.call end |
#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object
Gets API key (with prefix if set).
255 256 257 258 259 260 261 262 263 |
# File 'lib/docspring/configuration.rb', line 255 def api_key_with_prefix(param_name, param_alias = nil) key = @api_key[param_name] key = @api_key.fetch(param_alias, key) unless param_alias.nil? if @api_key_prefix[param_name] "#{@api_key_prefix[param_name]} #{key}" else key end end |
#api_token_id=(api_token_id) ⇒ Object
<————— BEGIN DOCSPRING CUSTOMIZATION —————–> Description: Add getter/setter for api_token_id and api_token_secret, aliases for username and password
202 203 204 |
# File 'lib/docspring/configuration.rb', line 202 def api_token_id=(api_token_id) @username = api_token_id end |
#api_token_secret=(api_token_secret) ⇒ Object
207 208 209 |
# File 'lib/docspring/configuration.rb', line 207 def api_token_secret=(api_token_secret) @password = api_token_secret end |
#auth_settings ⇒ Object
Returns Auth Settings hash for api client.
277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/docspring/configuration.rb', line 277 def auth_settings { 'api_token_basic' => { type: 'basic', in: 'header', key: 'Authorization', value: basic_auth_token }, } end |
#base_url(operation = nil) ⇒ Object
Returns base URL for specified operation based on server settings
243 244 245 246 247 248 249 250 251 |
# File 'lib/docspring/configuration.rb', line 243 def base_url(operation = nil) return "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') if ignore_operation_servers if operation_server_settings.key?(operation) then index = server_operation_index.fetch(operation, server_index) server_url(index.nil? ? 0 : index, server_operation_variables.fetch(operation, server_variables), operation_server_settings[operation]) else server_index.nil? ? "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') : server_url(server_index, server_variables, nil) end end |
#basic_auth_token ⇒ Object
Gets Basic Auth token string
272 273 274 |
# File 'lib/docspring/configuration.rb', line 272 def basic_auth_token 'Basic ' + ["#{username}:#{password}"].pack('m').delete("\r\n") end |
#configure {|_self| ... } ⇒ Object
218 219 220 |
# File 'lib/docspring/configuration.rb', line 218 def configure yield(self) if block_given? end |
#operation_server_settings ⇒ Object
299 300 301 302 |
# File 'lib/docspring/configuration.rb', line 299 def operation_server_settings { } end |
#server_settings ⇒ Object
Returns an array of Server setting
290 291 292 293 294 295 296 297 |
# File 'lib/docspring/configuration.rb', line 290 def server_settings [ { url: "https://api.docspring.com/api/v1", description: "No description provided", } ] end |
#server_url(index, variables = {}, servers = nil) ⇒ Object
Returns URL based on server settings
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/docspring/configuration.rb', line 308 def server_url(index, variables = {}, servers = nil) servers = server_settings if servers == nil # check array index out of bound if (index.nil? || index < 0 || index >= servers.size) fail ArgumentError, "Invalid index #{index} when selecting the server. Must not be nil and must be less than #{servers.size}" end server = servers[index] url = server[:url] return url unless server.key? :variables # go through variable and assign a value server[:variables].each do |name, variable| if variables.key?(name) if (!server[:variables][name].key?(:enum_values) || server[:variables][name][:enum_values].include?(variables[name])) url.gsub! "{" + name.to_s + "}", variables[name] else fail ArgumentError, "The variable `#{name}` in the server URL has invalid value #{variables[name]}. Must be #{server[:variables][name][:enum_values]}." end else # use default value url.gsub! "{" + name.to_s + "}", server[:variables][name][:default_value] end end url end |